@@ -156,7 +156,7 @@ class BinhostsBase(object):
             return ",".join(str(x) for x in args)
         else:
             return "%s|%s" % (",".join(str(x) for x in args),
-                              ",".join("%s:%s" % (str(k), str(v)) for x in
+                              ",".join("%s:%s" % (str(k), str(v)) for k, v in
                                        kw.items()))
 
 
